<?php

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class GS_main_class {


	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {

		wp_enqueue_script('jquery');
		
        wp_register_script( 'gs_popper-js', plugins_url( '/assets/js/popper-v1.14.3.min.js', __FILE__ ), [ 'jquery' ], false, true );
		 wp_enqueue_script( 'gs_popper-js' );

        wp_register_script( 'gs_bootstrap-js', plugins_url( '/assets/js/bootstrap-v4.1.3.min.js', __FILE__ ), [ 'jquery' ], false, true );
		 wp_enqueue_script( 'gs_bootstrap-js' );

        wp_register_script( 'gs_owl-carousel-js', plugins_url( '/assets/js/owl.carousel.min.js', __FILE__ ), [ 'jquery' ], false, true );
		 wp_enqueue_script( 'gs_owl-carousel-js' );
		 		 

	}
	
	/**
	 * widget_styles
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_styles(){
		wp_register_style("gs_font-awesome",plugins_url("/assets/css/font-awesome.min.css",__FILE__));
		wp_enqueue_style( 'gs_font-awesome' );

		wp_register_style("gs_owl-carousel",plugins_url("/assets/css/owl.carousel.min.css",__FILE__));
		wp_enqueue_style( 'gs_owl-carousel' );
		
		wp_register_style("gs_animate",plugins_url("/assets/css/animate.min.css",__FILE__));
		wp_enqueue_style( 'gs_animate' );
		
		wp_register_style("gs_bootstrap",plugins_url("/assets/css/bootstrap-v4.1.3.min.css",__FILE__));
		wp_enqueue_style( 'gs_bootstrap' );
		
		wp_register_style("gs_style",plugins_url("/assets/css/style.css",__FILE__));
		wp_enqueue_style( 'gs_style' );


	}	



	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {



		require_once( __DIR__ . '/inc/function.php' );
		require_once( __DIR__ . '/inc/general-slide.php' );
		require_once( __DIR__ . '/inc/CMB2/init.php');
		require_once( __DIR__ . '/inc/CMB2/options.php');
		require_once( __DIR__ . '/inc/shortcode-metabox.php');



		add_action( 'wp_enqueue_scripts', array( $this, 'widget_styles' ), 10 );
		add_action( 'wp_enqueue_scripts', array( $this, 'widget_scripts' ), 10 );


	}
}

// Instantiate Plugin Class
GS_main_class::instance();
